//#region src/adhoc-workspaces.d.ts
interface AdhocWorkspaceContent {
    /**
     * A map of relative file paths (e.g. `src/foo.html`) to their contents (strings). Binary
     * files aren't supported.
     */
    files: Record<string, string>;
    /**
     * Optional workspace configuration.
     */
    settings?: {
        /**
         * The starting point to build on.
         */
        baselineEnvironment?: 'flutter' | undefined;
    };
}
interface AdhocWorkspaceOptions {
    /**
     * Override base URL for the API.
     */
    url?: string;
    /**
     * Open Firebase Studio in a new browser tab/window.
     */
    newWindow?: boolean;
}
/**
* Creates a new ad-hoc Firebase Studio workspace from the given set of project files. For best
* effect, include a `.idx/dev.nix` file to customize the environment for the project.
*
* _NOTE: This is only supported in a browser environment._
*/
declare function newAdhocWorkspace(content: AdhocWorkspaceContent, options?: AdhocWorkspaceOptions): void;

//#endregion
//#region src/url.d.ts
type OpenDestination = ImportGitOpenDestination | NamedTemplateOpenDestination | CustomTemplateOpenDestination | PrototypePromptOpenDestination;
interface ImportGitOpenDestination {
    type: 'git';
    /**
     * The Git repository to import into a new workspace. This is essentially a `git clone` in a
     * new workspace.
     */
    repoUrl: string;
}
interface NamedTemplateOpenDestination {
    type: 'named-template';
    /**
     * The named template to create a new workspace from, for example `gemini`.
     */
    templateId: string;
}
interface CustomTemplateOpenDestination {
    type: 'custom-template';
    /**
     * The public Git repository URL for a custom template (a repo or subfolder with a
     * `idx-template.json` file).
     */
    templateRepoUrl: string;
}
interface PrototypePromptOpenDestination {
    type: 'prototype-prompt';
    /**
     * The natural language prompt for a prototype to build.
     */
    prompt: string;
}
/**
* Returns the URL for a given "Open in Firebase Studio" destination.
*/
declare function getOpenUrl(destination: OpenDestination, baseUrl?: string): string;

//#endregion
//#region src/button.d.ts
type ButtonLabel = 'open' | 'try' | 'export' | 'continue';
type ButtonColor = 'dark' | 'light' | 'blue' | 'bright';
type ButtonHtmlColor = ButtonColor | 'dynamic' | 'dynamic-reverse';
type ButtonSize = 20 | 32;
type ButtonImageFormat = 'svg' | 'png';
interface ButtonImageConfig {
    /**
     * The text label to show in the button.
     */
    label?: ButtonLabel;
    /**
     * The button color. 'Bright' is a branded gradient.
     */
    color?: ButtonColor;
    /**
     * The button height in pixels.
     */
    size?: ButtonSize;
    /**
     * The image format. PNG is served at @2x resolution.
     */
    imageFormat?: ButtonImageFormat;
}
interface ButtonHtmlConfig extends Omit<ButtonImageConfig, 'color'> {
    destination: OpenDestination;
    color?: ButtonHtmlColor;
}
/**
* Get the CDN URL for a given "Open in Firebase Studio" button image configuration.
*/
declare function getButtonImageUrl({ label, color, size, imageFormat }?: ButtonImageConfig): string;
/**
* Get the HTML for a given "Open in Firebase Studio" button configuration, including
* a target link.
*/
declare function getButtonHtml(config: ButtonHtmlConfig): string;

//#endregion
export { getButtonHtml, getButtonImageUrl, getOpenUrl, newAdhocWorkspace };